@@ -15,10 +15,11 @@ Copyright (C) 2010 Hiroki Ohtani(liris)
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA  02110-1335  USA
 
 """
 from ._core import *
 from ._app import WebSocketApp
 
-__version__ = "0.22.0"
+__version__ = "0.25.0"
