@@ -15,7 +15,8 @@ Copyright (C) 2010 Hiroki Ohtani(liris)
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA  02110-1335  USA
 
 """
 import six
@@ -100,15 +101,16 @@ class ABNF(object):
         self.data = data
         self.get_mask_key = os.urandom
 
-    def validate(self):
+    def validate(self, skip_utf8_validation=False):
         """
         validate the ABNF frame.
+        skip_utf8_validation: skip utf8 validation.
         """
         if self.rsv1 or self.rsv2 or self.rsv3:
             raise WebSocketProtocolException("rsv is not implemented, yet")
 
         if self.opcode not in ABNF.OPCODES:
-            raise WebSocketProtocolException("Invalid opcode " + self.opcode)
+            raise WebSocketProtocolException("Invalid opcode " + str(self.opcode))
 
         if self.opcode == ABNF.OPCODE_PING and not self.fin:
             raise WebSocketProtocolException("Invalid ping frame.")
@@ -119,7 +121,7 @@ class ABNF(object):
                 return
             if l == 1 or l >= 126:
                 raise WebSocketProtocolException("Invalid close frame.")
-            if l > 2 and not validate_utf8(self.data[2:]):
+            if l > 2 and not skip_utf8_validation and not validate_utf8(self.data[2:]):
                 raise WebSocketProtocolException("Invalid close frame.")
 
             code = 256*six.byte2int(self.data[0:1]) + six.byte2int(self.data[1:2])
