@@ -15,7 +15,8 @@ Copyright (C) 2010 Hiroki Ohtani(liris)
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA  02110-1335  USA
 
 """
 
@@ -94,7 +95,7 @@ class WebSocketApp(object):
         opcode: operation code of data. default is OPCODE_TEXT.
         """
 
-        if self.sock.send(data, opcode) == 0:
+        if not self.sock or self.sock.send(data, opcode) == 0:
             raise WebSocketConnectionClosedException()
 
     def close(self):
@@ -108,10 +109,12 @@ class WebSocketApp(object):
     def _send_ping(self, interval, event):
         while not event.wait(interval):
             self.last_ping_tm = time.time()
-            self.sock.ping()
+            if self.sock:
+                self.sock.ping()
 
     def run_forever(self, sockopt=None, sslopt=None, ping_interval=0, ping_timeout=None,
-        http_proxy_host=None, http_proxy_port=None):
+        http_proxy_host=None, http_proxy_port=None, http_no_proxy=None, http_proxy_auth=None,
+        skip_utf8_validation=False):
         """
         run event loop for WebSocket framework.
         This loop is infinite loop and is alive during websocket is available.
@@ -123,6 +126,8 @@ class WebSocketApp(object):
         ping_timeout: timeout(second) if the pong message is not recieved.
         http_proxy_host: http proxy host name.
         http_proxy_port: http proxy port. If not set, set to 80.
+        http_no_proxy: host names, which doesn't use proxy.
+        skip_utf8_validation: skip utf8 validation.
         """
 
         if not ping_timeout or ping_timeout<=0:
@@ -138,10 +143,12 @@ class WebSocketApp(object):
 
         try:
             self.sock = WebSocket(self.get_mask_key, sockopt=sockopt, sslopt=sslopt,
-                fire_cont_frame=self.on_cont_message and True or False)
+                fire_cont_frame=self.on_cont_message and True or False,
+                skip_utf8_validation=skip_utf8_validation)
             self.sock.settimeout(getdefaulttimeout())
             self.sock.connect(self.url, header=self.header, cookie=self.cookie,
                 http_proxy_host=http_proxy_host, http_proxy_port=http_proxy_port,
+                http_no_proxy=http_no_proxy, http_proxy_auth=http_proxy_auth,
                 subprotocols=self.subprotocols)
             self._callback(self.on_open)
 
@@ -196,7 +203,7 @@ class WebSocketApp(object):
             return []
 
         if data and len(data) >=2:
-            code = 256*six.byte2int(data[0]) + six.byte2int(data[1])
+            code = 256*six.byte2int(data[0:1]) + six.byte2int(data[1:2])
             reason = data[2:].decode('utf-8')
             return [code,reason]
         
