@@ -31,7 +31,8 @@ from websocket._utils import validate_utf8
 
 
 # Skip test to access the internet.
-TEST_WITH_INTERNET = False
+# TEST_WITH_INTERNET = False
+TEST_WITH_INTERNET = True
 
 # Skip Secure WebSocket test.
 TEST_SECURE_WS = False
@@ -257,12 +258,16 @@ class WebSocketTest(unittest.TestCase):
         s.add_packet(six.b("foo"))
         s.add_packet(socket.timeout())
         s.add_packet(six.b("bar"))
-        s.add_packet(SSLError("The read operation timed out"))
+        # s.add_packet(SSLError("The read operation timed out"))
         s.add_packet(six.b("baz"))
         with self.assertRaises(ws.WebSocketTimeoutException):
             data = sock._recv_strict(9)
-        with self.assertRaises(SSLError):
-            data = sock._recv_strict(9)
+        # if six.PY2:
+        #     with self.assertRaises(ws.WebSocketTimeoutException):
+        #         data = sock._recv_strict(9)
+        # else:
+        #     with self.assertRaises(SSLError):
+        #         data = sock._recv_strict(9)
         data = sock._recv_strict(9)
         self.assertEqual(data, six.b("foobarbaz"))
         with self.assertRaises(ws.WebSocketConnectionClosedException):
